@@ -41,7 +41,7 @@ class Point:
         res_order = np.argsort(res_cf)[::-1]
         self._cf_means = res_cf[res_order]
         self._res_gids = self._parse_list(res_gids, dtype=int)[res_order]
-        self._gid_counts = self._parse_list(gid_counts)[res_order]
+        self._gid_counts = self._parse_list(gid_counts, dtype=float)[res_order]
         self._res_capacity = \
             self._gid_counts / np.sum(self._gid_counts) * capacity
         self._avail_cap = self._res_capacity.copy()
@@ -558,7 +558,7 @@ class SupplyCurvePoints:
                                  .format((i + 1) * points_per_worker,
                                          len(sc_table)))
         else:
-            logger.info('Creating supply curve points in serial')
+            logger.debug('Creating supply curve points in serial')
             for i, (sc_gid, sc_point) in enumerate(sc_table.iterrows()):
                 sc_gid = int(sc_gid)
                 sc_points[sc_gid] = Point.create(sc_point, res_cf_means)
