@@ -1,7 +1,6 @@
 """
 Region Classifier Module
 """
-
 import numpy as np
 import pandas as pd
 import geopandas as gpd
@@ -10,6 +9,8 @@ from shapely.geometry import shape
 from scipy.spatial import cKDTree
 import logging
 
+from rex import Resource
+
 logger = logging.getLogger(__name__)
 
 
@@ -41,8 +42,9 @@ class RegionClassifier():
         """
         Parameters
         ----------
-        meta_path : str
-            Path to meta CSV file containing lat/lon points
+        meta_path : str | pandas.DataFrame
+            Path to meta CSV file, resource .h5 file, or pre-loaded meta
+            DataFrame containing lat/lon points
         regions_path : str
             Path to regions shapefile containing labeled geometries
         regions_label : str
@@ -53,53 +55,6 @@ class RegionClassifier():
         self._meta = self._get_meta(meta_path)
         self._regions = self._get_regions(regions_path, regions_label)
 
-    def classify(self, force=False):
-        """ Classify the meta data with regions labels
-
-        Parameters
-        ----------
-        force : str
-            Force outlier classification by finding nearest
-        """
-        try:
-            # Get intersection classifications
-            meta_inds, region_inds, outlier_inds = self._intersect()
-        except Exception as e:
-            logger.error(e)
-            invalid_geom_ids = self._check_geometry()
-            if invalid_geom_ids:
-                logger.error('The following geometries are invalid:')
-                logger.error(invalid_geom_ids)
-            else:
-                raise
-
-        # Check for any intersection outliers
-        num_outliers = len(outlier_inds)
-        if (num_outliers and force):
-            # Lookup the nearest region geometry (by centroid)
-            logger.warning('The following points are outliers:')
-            logger.warning(outlier_inds)
-            cols = self._get_lat_lon_labels(self._meta)
-            lookup = self._regions[['lat', 'lon']]
-            target = self._meta.loc[outlier_inds][cols]
-            region_inds += list(self._nearest(target, lookup))
-
-        # Get full list of meta indices and region labels
-        meta_inds += outlier_inds
-        region_labels = list(self._regions.loc[region_inds,
-                                               self._regions_label])
-        if (num_outliers and not force):
-            # Fill unclassified labels
-            region_labels += [-999 for _ in range(num_outliers)]
-
-        # Build classification mapping
-        region_labels = np.array(region_labels).astype(str)
-        classified_meta = self._meta.loc[meta_inds]
-        classified_meta[self._regions_label] = region_labels
-        classified_meta.sort_index(inplace=True)
-
-        return classified_meta
-
     @staticmethod
     def output_to_csv(gdf, path):
         """ Export a geopandas dataframe to csv
@@ -112,10 +67,13 @@ class RegionClassifier():
             Output CSV file path for labeled meta CSV file
         """
         output_gdf = gdf.drop('geometry', axis=1)
+        if output_gdf.index.name == 'gid':
+            output_gdf = output_gdf.reset_index()
+
         output_gdf.to_csv(path, index=False)
 
-    @classmethod
-    def _get_regions(cls, regions_path, regions_label):
+    @staticmethod
+    def _get_regions(regions_path, regions_label):
         """ Load the regions shapefile into geopandas dataframe
 
         Parameters
@@ -125,9 +83,9 @@ class RegionClassifier():
         regions_label : str
             Attribute to use as label in the regions shapefile
         """
-        regions = gpd.read_file(regions_path).to_crs(cls.CRS)
+        regions = gpd.read_file(regions_path).to_crs(RegionClassifier.CRS)
         if regions_label not in regions.columns:
-            regions_label = cls.DEFAULT_REGIONS_LABEL
+            regions_label = RegionClassifier.DEFAULT_REGIONS_LABEL
             regions[regions_label] = regions.index
             logger.warning('Setting regions label: {}'.format(regions_label))
 
@@ -137,20 +95,41 @@ class RegionClassifier():
 
         return regions
 
-    @classmethod
-    def _get_meta(cls, meta_path):
+    @staticmethod
+    def _get_meta(meta_path):
         """ Load the meta csv file into geopandas dataframe
 
         Parameters
         ----------
-        meta_path : str
-            Path to meta CSV file containing lat/lon points
+        meta_path : str | pandas.DataFrame
+            Path to meta CSV file, resource .h5 file, or pre-loaded meta
+            DataFrame containing lat/lon points
         """
-        meta = pd.read_csv(meta_path)
-        lat_label, long_label = cls._get_lat_lon_labels(meta)
+        if isinstance(meta_path, str):
+            if meta_path.endswith('.csv'):
+                meta = pd.read_csv(meta_path)
+            elif meta_path.endswith('.h5'):
+                with Resource(meta_path) as f:
+                    meta = f.meta
+            else:
+                msg = ("Cannot parse meta data from {}, expecting a .csv or "
+                       ".h5 file!".format(meta_path))
+                logger.error(msg)
+                raise RuntimeError(msg)
+        elif isinstance(meta_path, pd.DataFrame):
+            meta = meta_path
+        else:
+            msg = ("Cannot parse meta data from {}, expecting a .csv or "
+                   ".h5 file path, or a pre-loaded pandas DataFrame"
+                   .format(meta_path))
+            logger.error(msg)
+            raise RuntimeError(msg)
+
+        lat_label, long_label = RegionClassifier._get_lat_lon_labels(meta)
         geometry = [Point(xy) for xy in zip(meta[long_label],
                                             meta[lat_label])]
-        meta = gpd.GeoDataFrame(meta, crs=cls.CRS, geometry=geometry)
+        meta = gpd.GeoDataFrame(meta, crs=RegionClassifier.CRS,
+                                geometry=geometry)
 
         return meta
 
@@ -184,23 +163,6 @@ class RegionClassifier():
 
         return [lat_col, lon_col]
 
-    def _intersect(self):
-        """ Join the meta points to regions by spatial intersection """
-
-        joined = gpd.sjoin(self._meta, self._regions,
-                           how='inner', op='intersects')
-        if 'index_left' in joined.columns:
-            joined = joined.drop_duplicates('index_left', keep='last')
-            meta_inds = list(joined['index_left'])
-        else:
-            meta_inds = list(joined.index)
-
-        region_inds = list(joined['index_right'])
-        outliers = self._meta.loc[~self._meta.index.isin(meta_inds)]
-        outlier_inds = list(outliers.index)
-
-        return meta_inds, region_inds, outlier_inds
-
     @staticmethod
     def _nearest(target, lookup):
         """ Lookup the indices to the nearest point
@@ -226,6 +188,71 @@ class RegionClassifier():
         except AttributeError:
             return 0
 
+    def classify(self, force=False):
+        """ Classify the meta data with regions labels
+
+        Parameters
+        ----------
+        force : str
+            Force outlier classification by finding nearest
+        """
+        try:
+            # Get intersection classifications
+            meta_inds, region_inds, outlier_inds = self._intersect()
+        except Exception as e:
+            logger.warning(e)
+            invalid_geom_ids = self._check_geometry()
+            if invalid_geom_ids:
+                logger.warning('The following geometries are invalid: {}'
+                               .format(invalid_geom_ids))
+            else:
+                logger.exception('Cannot run region classification')
+                raise
+
+        # Check for any intersection outliers
+        num_outliers = len(outlier_inds)
+        if (num_outliers and force):
+            # Lookup the nearest region geometry (by centroid)
+            logger.warning('The following points are outliers:')
+            logger.warning(outlier_inds)
+            cols = self._get_lat_lon_labels(self._meta)
+            lookup = self._regions[['lat', 'lon']]
+            target = self._meta.loc[outlier_inds][cols]
+            region_inds += list(self._nearest(target, lookup))
+
+        # Get full list of meta indices and region labels
+        meta_inds += outlier_inds
+        region_labels = list(self._regions.loc[region_inds,
+                                               self._regions_label])
+        if (num_outliers and not force):
+            # Fill unclassified labels
+            region_labels += [-999 for _ in range(num_outliers)]
+
+        # Build classification mapping
+        region_labels = np.array(region_labels).astype(str)
+        classified_meta = self._meta.loc[meta_inds]
+        classified_meta[self._regions_label] = region_labels
+        classified_meta.sort_index(inplace=True)
+
+        return classified_meta
+
+    def _intersect(self):
+        """ Join the meta points to regions by spatial intersection """
+
+        joined = gpd.sjoin(self._meta, self._regions,
+                           how='inner', op='intersects')
+        if 'index_left' in joined.columns:
+            joined = joined.drop_duplicates('index_left', keep='last')
+            meta_inds = list(joined['index_left'])
+        else:
+            meta_inds = list(joined.index)
+
+        region_inds = list(joined['index_right'])
+        outliers = self._meta.loc[~self._meta.index.isin(meta_inds)]
+        outlier_inds = list(outliers.index)
+
+        return meta_inds, region_inds, outlier_inds
+
     def _check_geometry(self):
         """ Get index list of invalid geometries """
         geometry = self._regions.geometry
@@ -240,8 +267,9 @@ class RegionClassifier():
 
         Parameters
         ----------
-        meta_path : str
-            Path to meta CSV file containing lat/lon points
+        meta_path : str | pandas.DataFrame
+            Path to meta CSV file, resource .h5 file, or pre-loaded meta
+            DataFrame containing lat/lon points
         regions_path : str
             Path to regions shapefile containing labeled geometries
         regions_label : str
